# geotifflib

GeoTiffLib primarily offers a set of utility functions for reading, saving, and processing GeoTIFF image files.

## Install

由于使用pip安装GDAL报错，因此安装此包之前需要使用conda安装GDAL：

```sh
conda install GDAL
```

安装GDAL完成之后再安装本包：

```sh
pip install geotifflib
```
